@@ -5,7 +5,15 @@ from typing import *
 
 from cognite.client import utils
 from cognite.client._api_client import APIClient
-from cognite.client.data_classes import Asset, AssetAggregate, AssetFilter, AssetList, AssetUpdate, TimestampRange
+from cognite.client.data_classes import (
+    Asset,
+    AssetAggregate,
+    AssetFilter,
+    AssetList,
+    AssetUpdate,
+    TimestampRange,
+    LabelFilter,
+)
 from cognite.client.exceptions import CogniteAPIError
 
 
@@ -26,6 +34,7 @@ class AssetsAPI(APIClient):
         metadata: Dict[str, str] = None,
         data_set_ids: List[int] = None,
         data_set_external_ids: List[str] = None,
+        labels: LabelFilter = None,
         source: str = None,
         created_time: Union[Dict[str, Any], TimestampRange] = None,
         last_updated_time: Union[Dict[str, Any], TimestampRange] = None,
@@ -50,6 +59,7 @@ class AssetsAPI(APIClient):
             metadata (Dict[str, str]): Custom, application specific metadata. String key -> String value
             data_set_ids (List[int]): Return only assets in the specified data sets with these ids.
             data_set_external_ids (List[str]): Return only assets in the specified data sets with these external ids.
+            labels (LabelFilter): Return only the assets matching the specified label.
             source (str): The source of this asset
             created_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
             last_updated_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
@@ -78,6 +88,7 @@ class AssetsAPI(APIClient):
             root_ids=root_ids,
             asset_subtree_ids=asset_subtree_ids,
             data_set_ids=data_set_ids,
+            labels=labels,
             metadata=metadata,
             source=source,
             created_time=created_time,
@@ -177,6 +188,7 @@ class AssetsAPI(APIClient):
         asset_subtree_external_ids: List[str] = None,
         data_set_ids: List[int] = None,
         data_set_external_ids: List[str] = None,
+        labels: LabelFilter = None,
         metadata: Dict[str, str] = None,
         source: str = None,
         created_time: Union[Dict[str, Any], TimestampRange] = None,
@@ -199,6 +211,7 @@ class AssetsAPI(APIClient):
             asset_subtree_external_ids (List[str]): List of asset subtrees external ids to filter on.
             data_set_ids (List[int]): Return only assets in the specified data sets with these ids.
             data_set_external_ids (List[str]): Return only assets in the specified data sets with these external ids.
+            labels (LabelFilter): Return only the assets matching the specified label filter.
             metadata (Dict[str, str]): Custom, application specific metadata. String key -> String value.
             source (str): The source of this asset.
             created_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
@@ -234,6 +247,14 @@ class AssetsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> for asset_list in c.assets(chunk_size=2500):
                 ...     asset_list # do something with the assets
+
+            Filter assets based on labels::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import LabelFilter
+                >>> c = CogniteClient()
+                >>> my_label_filter = LabelFilter(contains_all=["PUMP", "VERIFIED"])
+                >>> asset_list = c.assets.list(labels=my_label_filter)
         """
         if aggregated_properties:
             aggregated_properties = [utils._auxiliary.to_camel_case(s) for s in aggregated_properties]
@@ -253,6 +274,7 @@ class AssetsAPI(APIClient):
             root_ids=root_ids,
             asset_subtree_ids=asset_subtree_ids,
             data_set_ids=data_set_ids,
+            labels=labels,
             metadata=metadata,
             source=source,
             created_time=created_time,
@@ -308,6 +330,14 @@ class AssetsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> assets = [Asset(name="asset1"), Asset(name="asset2")]
                 >>> res = c.assets.create(assets)
+
+            Create asset with label::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import Asset, Label
+                >>> c = CogniteClient()
+                >>> asset = Asset(name="my_pump", labels=[Label(external_id="PUMP")])
+                >>> res = c.assets.create(assets)
         """
         utils._auxiliary.assert_type(asset, "asset", [Asset, list])
         return self._create_multiple(asset)
@@ -372,6 +402,7 @@ class AssetsAPI(APIClient):
 
     def update(self, item: Union[Asset, AssetUpdate, List[Union[Asset, AssetUpdate]]]) -> Union[Asset, AssetList]:
         """`Update one or more assets <https://docs.cognite.com/api/v1/#operation/updateAssets>`_
+        Currently, a full replacement of labels on an asset is not supported (only partial add/remove updates). See the example below on how to perform partial labels update.
 
         Args:
             item (Union[Asset, AssetUpdate, List[Union[Asset, AssetUpdate]]]): Asset(s) to update
@@ -396,6 +427,22 @@ class AssetsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> my_update = AssetUpdate(id=1).description.set("New description").metadata.add({"key": "value"})
                 >>> res = c.assets.update(my_update)
+
+            Attach a label to an asset::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import AssetUpdate
+                >>> c = CogniteClient()
+                >>> my_update = AssetUpdate(id=1).labels.add(["PUMP"])
+                >>> res = c.assets.update(my_update)
+
+            Detach a label from an asset::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import AssetUpdate
+                >>> c = CogniteClient()
+                >>> my_update = AssetUpdate(id=1).labels.remove(["PUMP"])
+                >>> res = c.assets.update(my_update)
         """
         return self._update_multiple(items=item)
 
