@@ -410,9 +410,6 @@ class ThreeDRevisionsAPI(APIClient):
     ) -> ThreeDNodeList:
         """`Retrieves a list of ancestor nodes of a given node, including itself, in the hierarchy of the 3D model <https://docs.cognite.com/api/v1/#operation/get3DNodeAncestors>`_
 
-        You can also request a specific subtree with the 'nodeId' query parameter and limit the depth of
-        the resulting subtree with the 'depth' query parameter.
-
         Args:
             model_id (int): Id of the model.
             revision_id (int): Id of the revision.
@@ -549,7 +546,7 @@ class ThreeDAssetMappingAPI(APIClient):
         if isinstance(asset_mapping, ThreeDAssetMapping):
             asset_mapping = [asset_mapping]
         chunks = utils._auxiliary.split_into_chunks(
-            [a.dump(camel_case=True) for a in asset_mapping], self._DELETE_LIMIT
+            [ThreeDAssetMapping(a.node_id, a.asset_id).dump(camel_case=True) for a in asset_mapping], self._DELETE_LIMIT
         )
         tasks = [{"url_path": path + "/delete", "json": {"items": chunk}} for chunk in chunks]
         summary = utils._concurrency.execute_tasks_concurrently(self._post, tasks, self._config.max_workers)
