@@ -3,9 +3,9 @@ from typing import *
 
 from cognite.client.data_classes._base import *
 from cognite.client.data_classes.shared import TimestampRange
+from cognite.client.data_classes.labels import Label, LabelFilter
 
 
-# GenPropertyClass: AssetAggregate
 class AssetAggregate(dict):
     """Aggregation group of assets
 
@@ -19,10 +19,7 @@ class AssetAggregate(dict):
 
     count = CognitePropertyClassUtil.declare_property("count")
 
-    # GenStop
 
-
-# GenPropertyClass: AggregateResultItem
 class AggregateResultItem(dict):
     """Aggregated metrics of the asset
 
@@ -42,10 +39,7 @@ class AggregateResultItem(dict):
     depth = CognitePropertyClassUtil.declare_property("depth")
     path = CognitePropertyClassUtil.declare_property("path")
 
-    # GenStop
 
-
-# GenClass: Asset, DataExternalAssetItem
 class Asset(CogniteResource):
     """A representation of a physical asset, for example a factory or a piece of equipment.
 
@@ -58,6 +52,7 @@ class Asset(CogniteResource):
         data_set_id (int): The id of the dataset this asset belongs to.
         metadata (Dict[str, str]): Custom, application specific metadata. String key -> String value. Limits: Maximum length of key is 128 bytes, value 10240 bytes, up to 256 key-value pairs, of total size at most 10240.
         source (str): The source of the asset.
+        labels (List[Label]): A list of the labels associated with this resource item.
         id (int): A server-generated ID for the object.
         created_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
         last_updated_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
@@ -76,6 +71,7 @@ class Asset(CogniteResource):
         data_set_id: int = None,
         metadata: Dict[str, str] = None,
         source: str = None,
+        labels: List[Label] = None,
         id: int = None,
         created_time: int = None,
         last_updated_time: int = None,
@@ -83,6 +79,8 @@ class Asset(CogniteResource):
         aggregates: Union[Dict[str, Any], AggregateResultItem] = None,
         cognite_client=None,
     ):
+        if labels is not None and len(labels) > 0 and not isinstance(labels[0], Label):
+            raise TypeError("Asset.labels should be of type List[Label]")
         self.external_id = external_id
         self.name = name
         self.parent_id = parent_id
@@ -91,6 +89,7 @@ class Asset(CogniteResource):
         self.data_set_id = data_set_id
         self.metadata = metadata
         self.source = source
+        self.labels = labels
         self.id = id
         self.created_time = created_time
         self.last_updated_time = last_updated_time
@@ -104,10 +103,10 @@ class Asset(CogniteResource):
         if isinstance(resource, Dict):
             if instance.aggregates is not None:
                 instance.aggregates = AggregateResultItem(**instance.aggregates)
+        if instance.labels is not None:
+            instance.labels = [Label._load(label) for label in instance.labels]
         return instance
 
-    # GenStop
-
     def __hash__(self):
         return hash(self.external_id)
 
@@ -173,6 +172,12 @@ class Asset(CogniteResource):
         """
         return self._cognite_client.files.list(asset_ids=[self.id], **kwargs)
 
+    def dump(self, camel_case: bool = False):
+        result = super(Asset, self).dump(camel_case)
+        if self.labels is not None:
+            result["labels"] = [label.dump(camel_case) for label in self.labels]
+        return result
+
     def to_pandas(
         self, expand: List[str] = ("metadata", "aggregates"), ignore: List[str] = None, camel_case: bool = True
     ):
@@ -189,7 +194,6 @@ class Asset(CogniteResource):
         return super().to_pandas(expand=expand, ignore=ignore, camel_case=camel_case)
 
 
-# GenUpdateClass: AssetChange
 class AssetUpdate(CogniteUpdate):
     """Changes applied to asset
 
@@ -198,66 +202,72 @@ class AssetUpdate(CogniteUpdate):
         external_id (str): The external ID provided by the client. Must be unique for the resource type.
     """
 
+    class _PrimitiveAssetUpdate(CognitePrimitiveUpdate):
+        def set(self, value: Any) -> "AssetUpdate":
+            return self._set(value)
+
+    class _ObjectAssetUpdate(CogniteObjectUpdate):
+        def set(self, value: Dict) -> "AssetUpdate":
+            return self._set(value)
+
+        def add(self, value: Dict) -> "AssetUpdate":
+            return self._add(value)
+
+        def remove(self, value: List) -> "AssetUpdate":
+            return self._remove(value)
+
+    class _ListAssetUpdate(CogniteListUpdate):
+        def set(self, value: List) -> "AssetUpdate":
+            return self._set(value)
+
+        def add(self, value: List) -> "AssetUpdate":
+            return self._add(value)
+
+        def remove(self, value: List) -> "AssetUpdate":
+            return self._remove(value)
+
+    class _LabelAssetUpdate(CogniteLabelUpdate):
+        def add(self, value: List[str]) -> "AssetUpdate":
+            return self._add(value)
+
+        def remove(self, value: List[str]) -> "AssetUpdate":
+            return self._remove(value)
+
     @property
     def external_id(self):
-        return _PrimitiveAssetUpdate(self, "externalId")
+        return AssetUpdate._PrimitiveAssetUpdate(self, "externalId")
 
     @property
     def name(self):
-        return _PrimitiveAssetUpdate(self, "name")
+        return AssetUpdate._PrimitiveAssetUpdate(self, "name")
 
     @property
     def description(self):
-        return _PrimitiveAssetUpdate(self, "description")
+        return AssetUpdate._PrimitiveAssetUpdate(self, "description")
 
     @property
     def data_set_id(self):
-        return _PrimitiveAssetUpdate(self, "dataSetId")
+        return AssetUpdate._PrimitiveAssetUpdate(self, "dataSetId")
 
     @property
     def metadata(self):
-        return _ObjectAssetUpdate(self, "metadata")
+        return AssetUpdate._ObjectAssetUpdate(self, "metadata")
 
     @property
     def source(self):
-        return _PrimitiveAssetUpdate(self, "source")
+        return AssetUpdate._PrimitiveAssetUpdate(self, "source")
 
     @property
     def parent_id(self):
-        return _PrimitiveAssetUpdate(self, "parentId")
+        return AssetUpdate._PrimitiveAssetUpdate(self, "parentId")
 
     @property
     def parent_external_id(self):
-        return _PrimitiveAssetUpdate(self, "parentExternalId")
+        return AssetUpdate._PrimitiveAssetUpdate(self, "parentExternalId")
 
-
-class _PrimitiveAssetUpdate(CognitePrimitiveUpdate):
-    def set(self, value: Any) -> AssetUpdate:
-        return self._set(value)
-
-
-class _ObjectAssetUpdate(CogniteObjectUpdate):
-    def set(self, value: Dict) -> AssetUpdate:
-        return self._set(value)
-
-    def add(self, value: Dict) -> AssetUpdate:
-        return self._add(value)
-
-    def remove(self, value: List) -> AssetUpdate:
-        return self._remove(value)
-
-
-class _ListAssetUpdate(CogniteListUpdate):
-    def set(self, value: List) -> AssetUpdate:
-        return self._set(value)
-
-    def add(self, value: List) -> AssetUpdate:
-        return self._add(value)
-
-    def remove(self, value: List) -> AssetUpdate:
-        return self._remove(value)
-
-    # GenStop
+    @property
+    def labels(self):
+        return AssetUpdate._LabelAssetUpdate(self, "labels")
 
 
 class AssetList(CogniteResourceList):
@@ -335,7 +345,6 @@ class AssetList(CogniteResourceList):
         return resources
 
 
-# GenClass: AssetFilter.filter
 class AssetFilter(CogniteFilter):
     """Filter on assets with strict matching.
 
@@ -352,6 +361,7 @@ class AssetFilter(CogniteFilter):
         last_updated_time (Union[Dict[str, Any], TimestampRange]): Range between two timestamps.
         root (bool): Whether the filtered assets are root assets, or not. Set to True to only list root assets.
         external_id_prefix (str): Filter by this (case-sensitive) prefix for the external ID.
+        labels (LabelFilter): Return only the resource matching the specified label constraints.
         cognite_client (CogniteClient): The client to associate with this object.
     """
 
@@ -369,6 +379,7 @@ class AssetFilter(CogniteFilter):
         last_updated_time: Union[Dict[str, Any], TimestampRange] = None,
         root: bool = None,
         external_id_prefix: str = None,
+        labels: LabelFilter = None,
         cognite_client=None,
     ):
         self.name = name
@@ -383,8 +394,12 @@ class AssetFilter(CogniteFilter):
         self.last_updated_time = last_updated_time
         self.root = root
         self.external_id_prefix = external_id_prefix
+        self.labels = labels
         self._cognite_client = cognite_client
 
+        if labels is not None and not isinstance(labels, LabelFilter):
+            raise TypeError("AssetFilter.labels must be of type LabelFilter")
+
     @classmethod
     def _load(cls, resource: Union[Dict, str], cognite_client=None):
         instance = super(AssetFilter, cls)._load(resource, cognite_client)
@@ -395,4 +410,8 @@ class AssetFilter(CogniteFilter):
                 instance.last_updated_time = TimestampRange(**instance.last_updated_time)
         return instance
 
-    # GenStop
+    def dump(self, camel_case: bool = False):
+        result = super(AssetFilter, self).dump(camel_case)
+        if isinstance(self.labels, LabelFilter):
+            result["labels"] = self.labels.dump(camel_case)
+        return result
